<template>
  <div class="app-container">
    <el-row class="roleBox">
      <el-col :span="24" class="roleCol">
        <div class="roleH"></div>
        <span>功能权限</span>
      </el-col>
      <el-col :span="24" class="roleBot">
        <el-row :gutter="10" class="mb8">
        <el-col :span="1.5">
          <el-button type="primary" style="background-color: #2AC1CA;color: #fff;border: none;" plain icon="el-icon-plus"
            @click="handleAdd" v-hasPermi="['system:role:add']">新增</el-button>
        </el-col>
        <el-col :span="1.5">
          <el-button type="primary" style="background-color: #FF9639;color: #fff;border: none;" plain icon="el-icon-refresh"
            @click="handleAdd" v-hasPermi="['system:role:list']">刷新</el-button>
        </el-col>
        <el-col :span="1.5">
          <el-button type="primary" style="background-color: #3C8DBC;color: #fff;border: none;" plain icon="el-icon-my-export"
            @click="handleAdd" v-hasPermi="['system:role:edit']">保存</el-button>
        </el-col>
        </el-row>
      </el-col>
      </el-row>
    <el-row style="margin-top: 18px;">
      <el-col :span="5" class="searBoxs">
        <div class="searBox">
          <div class="searInput">
            <input type="text" placeholder="请输入角色">
          </div>
          <div class="searBtn">
            <img src="@/assets/images/icon_sr_ss@2x.png" alt="" class="icon">
          </div>
        </div>
        <div class="searList">
          <div class="searItem" v-for="item in roleList" :class="{'active': false}">
            {{item.roleName}}
          </div>
        </div>
      </el-col>
      <el-col :span="19" class="roleContr">
        <div class="roleContrBox">
          <el-col :span="7">
            <div class="searContLeft">
              <el-tree :data="data" :props="defaultProps" @node-click="handleNodeClick"></el-tree>
            </div>
          </el-col>
          <el-col :span="17">
            <div class="searContRight">
              <div class="searTitle">
                <div class="searName">
                  功能
                </div>
                <div class="searItem" v-for="item in 8">
                  <el-checkbox :label="'新增'+item"></el-checkbox>
                </div>
              </div>
              <div class="searCont" v-for="items in 12" @click="searIndex = item" :class="{'active': searIndex == item}">
                <div class="searName">
                  功能功能{{items}}
                </div>
                <div class="searItem" v-for="item in 8">
                  <el-checkbox></el-checkbox>
                </div>
              </div>
            </div>
          </el-col>
        </div>
      </el-col>
    </el-row>
  </div>
</template>

<script>
  import { listRole, getRole, delRole, addRole, updateRole, exportRole, dataScope, changeRoleStatus } from "@/api/system/role";
  import { treeselect as menuTreeselect, roleMenuTreeselect } from "@/api/system/menu";
  import { treeselect as deptTreeselect, roleDeptTreeselect } from "@/api/system/dept";

  export default {
    name: "Role",
    data() {
      return {
        searIndex: '',
        data: [{
          label: '一级 1',
          children: [{
            label: '二级 1-1',
            children: [{
              label: '三级 1-1-1'
            }]
          }]
        }, {
          label: '一级 2',
          children: [{
            label: '二级 2-1',
            children: [{
              label: '三级 2-1-1'
            }]
          }, {
            label: '二级 2-2',
            children: [{
              label: '三级 2-2-1'
            }]
          }]
        }, {
          label: '一级 3',
          children: [{
            label: '二级 3-1',
            children: [{
              label: '三级 3-1-1'
            }]
          }, {
            label: '二级 3-2',
            children: [{
              label: '三级 3-2-1'
            }]
          }]
        }],
        defaultProps: {
          children: 'children',
          label: 'label'
        },
        indexs: 3,
        // 遮罩层
        loading: true,
        // 选中数组
        ids: [],
        // 非单个禁用
        single: true,
        // 非多个禁用
        multiple: true,
        // 显示搜索条件
        showSearch: true,
        // 总条数
        total: 0,
        // 角色表格数据
        roleList: [],
        // 弹出层标题
        title: "",
        // 是否显示弹出层
        open: false,
        // 是否显示弹出层（数据权限）
        openDataScope: false,
        menuExpand: false,
        menuNodeAll: false,
        deptExpand: true,
        deptNodeAll: false,
        // 日期范围
        dateRange: [],
        // 状态数据字典
        statusOptions: [],
        // 数据范围选项
        dataScopeOptions: [{
            value: "1",
            label: "全部数据权限"
          },
          {
            value: "2",
            label: "自定数据权限"
          },
          {
            value: "3",
            label: "本部门数据权限"
          },
          {
            value: "4",
            label: "本部门及以下数据权限"
          },
          {
            value: "5",
            label: "仅本人数据权限"
          }
        ],
        // 菜单列表
        menuOptions: [],
        // 部门列表
        deptOptions: [],
        // 查询参数
        queryParams: {
          pageNum: 1,
          pageSize: 10,
          roleName: undefined,
          roleKey: undefined,
          status: undefined
        },
        // 表单参数
        form: {},
        defaultProps: {
          children: "children",
          label: "label"
        },
        // 表单校验
        rules: {
          roleName: [{
            required: true,
            message: "角色名称不能为空",
            trigger: "blur"
          }],
          roleKey: [{
            required: true,
            message: "权限字符不能为空",
            trigger: "blur"
          }],
          roleSort: [{
            required: true,
            message: "角色顺序不能为空",
            trigger: "blur"
          }]
        }
      };
    },
    created() {
      this.getList();
      this.getDicts("sys_normal_disable").then(response => {
        this.statusOptions = response.data;
      });
    },
    methods: {
      handleNodeClick() {
        console.log(221)
      },
      /** 查询角色列表 */
      getList() {
        this.loading = true;
        listRole(this.addDateRange(this.queryParams, this.dateRange)).then(
          response => {
            this.roleList = response.rows;
            this.total = response.total;
            this.loading = false;
          }
        );
      },
      /** 查询菜单树结构 */
      getMenuTreeselect() {
        menuTreeselect().then(response => {
          this.menuOptions = response.data;
        });
      },
      /** 查询部门树结构 */
      getDeptTreeselect() {
        deptTreeselect().then(response => {
          this.deptOptions = response.data;
        });
      },
      // 所有菜单节点数据
      getMenuAllCheckedKeys() {
        // 目前被选中的菜单节点
        let checkedKeys = this.$refs.menu.getCheckedKeys();
        // 半选中的菜单节点
        let halfCheckedKeys = this.$refs.menu.getHalfCheckedKeys();
        checkedKeys.unshift.apply(checkedKeys, halfCheckedKeys);
        return checkedKeys;
      },
      // 所有部门节点数据
      getDeptAllCheckedKeys() {
        // 目前被选中的部门节点
        let checkedKeys = this.$refs.dept.getCheckedKeys();
        // 半选中的部门节点
        let halfCheckedKeys = this.$refs.dept.getHalfCheckedKeys();
        checkedKeys.unshift.apply(checkedKeys, halfCheckedKeys);
        return checkedKeys;
      },
      /** 根据角色ID查询菜单树结构 */
      getRoleMenuTreeselect(id) {
        return roleMenuTreeselect(id).then(response => {
          this.menuOptions = response.menus;
          return response;
        });
      },
      /** 根据角色ID查询部门树结构 */
      getRoleDeptTreeselect(id) {
        return roleDeptTreeselect(id).then(response => {
          this.deptOptions = response.depts;
          return response;
        });
      },
      // 角色状态修改
      handleStatusChange(row) {
        let text = row.status === "0" ? "启用" : "停用";
        this.$confirm('确认要"' + text + '""' + row.roleName + '"角色吗?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return changeRoleStatus(row.id, row.status);
        }).then(() => {
          this.msgSuccess(text + "成功");
        }).catch(function() {
          row.status = row.status === "0" ? "1" : "0";
        });
      },
      // 取消按钮
      cancel() {
        this.open = false;
        this.reset();
      },
      // 取消按钮（数据权限）
      cancelDataScope() {
        this.openDataScope = false;
        this.reset();
      },
      // 表单重置
      reset() {
        if (this.$refs.menu != undefined) {
          this.$refs.menu.setCheckedKeys([]);
        }
        this.menuExpand = false,
          this.menuNodeAll = false,
          this.deptExpand = true,
          this.deptNodeAll = false,
          this.form = {
            id: undefined,
            roleName: undefined,
            roleKey: undefined,
            roleSort: 0,
            status: "0",
            menuIds: [],
            deptIds: [],
            menuCheckStrictly: true,
            deptCheckStrictly: true,
            remark: undefined
          };
        this.resetForm("form");
      },
      /** 搜索按钮操作 */
      handleQuery() {
        this.queryParams.pageNum = 1;
        this.getList();
      },
      /** 重置按钮操作 */
      resetQuery() {
        this.dateRange = [];
        this.resetForm("queryForm");
        this.handleQuery();
      },
      // 多选框选中数据
      handleSelectionChange(selection) {
        this.ids = selection.map(item => item.id)
        this.single = selection.length != 1
        this.multiple = !selection.length
      },
      // 树权限（展开/折叠）
      handleCheckedTreeExpand(value, type) {
        if (type == 'menu') {
          let treeList = this.menuOptions;
          for (let i = 0; i < treeList.length; i++) {
            this.$refs.menu.store.nodesMap[treeList[i].id].expanded = value;
          }
        } else if (type == 'dept') {
          let treeList = this.deptOptions;
          for (let i = 0; i < treeList.length; i++) {
            this.$refs.dept.store.nodesMap[treeList[i].id].expanded = value;
          }
        }
      },
      // 树权限（全选/全不选）
      handleCheckedTreeNodeAll(value, type) {
        if (type == 'menu') {
          this.$refs.menu.setCheckedNodes(value ? this.menuOptions : []);
        } else if (type == 'dept') {
          this.$refs.dept.setCheckedNodes(value ? this.deptOptions : []);
        }
      },
      // 树权限（父子联动）
      handleCheckedTreeConnect(value, type) {
        if (type == 'menu') {
          this.form.menuCheckStrictly = value ? true : false;
        } else if (type == 'dept') {
          this.form.deptCheckStrictly = value ? true : false;
        }
      },
      /** 新增按钮操作 */
      handleAdd() {
        this.reset();
        this.getMenuTreeselect();
        this.open = true;
        this.title = "添加角色";
      },
      /** 修改按钮操作 */
      handleUpdate(row) {
        this.reset();
        const id = row.id || this.ids
        const roleMenu = this.getRoleMenuTreeselect(id);
        getRole(id).then(response => {
          this.form = response.data;
          this.open = true;
          this.$nextTick(() => {
            roleMenu.then(res => {
              let checkedKeys = res.checkedKeys
              checkedKeys.forEach((v) => {
                this.$nextTick(() => {
                  this.$refs.menu.setChecked(v, true, false);
                })
              })
            });
          });
          this.title = "修改角色";
        });
      },
      /** 选择角色权限范围触发 */
      dataScopeSelectChange(value) {
        if (value !== '2') {
          this.$refs.dept.setCheckedKeys([]);
        }
      },
      /** 分配数据权限操作 */
      handleDataScope(row) {
        this.reset();
        const roleDeptTreeselect = this.getRoleDeptTreeselect(row.id);
        getRole(row.id).then(response => {
          this.form = response.data;
          this.openDataScope = true;
          this.$nextTick(() => {
            roleDeptTreeselect.then(res => {
              this.$refs.dept.setCheckedKeys(res.checkedKeys);
            });
          });
          this.title = "分配数据权限";
        });
      },
      /** 提交按钮 */
      submitForm: function() {
        this.$refs["form"].validate(valid => {
          if (valid) {
            if (this.form.id != undefined) {
              this.form.menuIds = this.getMenuAllCheckedKeys();
              updateRole(this.form).then(response => {
                this.msgSuccess("修改成功");
                this.open = false;
                this.getList();
              });
            } else {
              this.form.menuIds = this.getMenuAllCheckedKeys();
              addRole(this.form).then(response => {
                this.msgSuccess("新增成功");
                this.open = false;
                this.getList();
              });
            }
          }
        });
      },
      /** 提交按钮（数据权限） */
      submitDataScope: function() {
        if (this.form.id != undefined) {
          this.form.deptIds = this.getDeptAllCheckedKeys();
          dataScope(this.form).then(response => {
            this.msgSuccess("修改成功");
            this.openDataScope = false;
            this.getList();
          });
        }
      },
      /** 删除按钮操作 */
      handleDelete(row) {
        const ids = row.id || this.ids;
        this.$confirm('是否确认删除角色编号为"' + ids + '"的数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delRole(ids);
        }).then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        })
      },
      /** 导出按钮操作 */
      handleExport() {
        this.download('system/role/export', {
          ...this.queryParams
        }, `role_${new Date().getTime()}.xlsx`)
      }
    }
  };
</script>
<style lang="scss" scoped>
  .roleContrBox {
    background-color: #fff;
    border-radius: 6px;
    overflow: hidden;
    padding: 23px 0;
  }

  .roleContr {
    padding-left: 17px;

    .searContLeft {
      padding: 23px 17px 23px 23px;
      border-right: 2px solid #E5E5E5;
    }

    .searContRight {
      padding-left: 18px;

      .searTitle {
        display: flex;
        padding-left: 11px;
        margin-bottom: 26px;

        .searName {
          color: #343434;
          font-size: 12px;
          width: 156px;
        }

        .searItem {
          flex: 1;
          font-size: 12px;
        }
      }

      .searCont {
        display: flex;
        height: 23px;
        padding-left: 11px;
        align-items: center;
        margin-bottom: 4px;
        cursor: pointer;

        .searName {
          color: #343434;
          font-size: 12px;
          width: 156px;
        }

        .searItem {
          flex: 1;
          font-size: 12px;
        }

        &:hover {
          background-color: rgba(0, 0, 0, .1);
        }
      }

      .active {
        background-color: #CADBE4;

        .searName {
          color: #fff;
        }
      }
    }
  }

  .searBoxs {
    background-color: #fff;
    border-radius: 6px;
    padding: 23px;

    .searBox {
      display: flex;

      .searInput {
        flex: 1;
        height: 32px;
        margin-right: 8px;
        box-sizing: border-box;
      }

      input {
        width: 100%;
        height: 100%;
        background-color: #F7F6F6;
        border: none;
        padding: 0 7px;
        outline: none;

        &::placeholder {
          color: #AAAAAA;
          font-size: 12px;
        }
      }

      .searBtn {
        width: 30px;
        height: 32px;
        display: flex;
        justify-content: center;
        align-items: center;
        background-color: #3C8DBC;
        cursor: pointer;

        .icon {
          width: 18px;
          height: 17px;
        }
      }
    }

    .searList {
      padding: 10px 0;

      .searItem {
        padding: 0 8px;
        line-height: 30px;
        font-size: 12px;
        color: #343434;
        cursor: pointer;
      }

      .active {
        background-color: #CADBE4;
        color: #3C8DBC;
      }
    }
  }

  .app-container {
    background-color: #EFF0FF;
    min-height: calc(100vh - 70px);
    box-sizing: border-box;
    box-sizing: border-box;
  }

  .roleBox {
    padding: 0 23px;
    background: #fff;
    border-radius: 6px;

    .roleCol {
      padding: 20px 0;
      border-bottom: 1px solid #E5E5E5;

      .roleH {
        width: 18px;
        height: 8px;
        border-radius: 4px;
        background-color: #3C8DBC;
        margin-bottom: 8px;
      }

      span {
        font-size: 15px;
        color: #3C8DBC;
      }
    }

    .roleBot {
      padding: 22px 0;

      .roleBtn {
        height: 32px;
        display: flex;
        border-radius: 3px;
        justify-content: center;
        align-items: center;
        width: 83px;
        margin-right: 18px;

        .icon {
          width: 14px;
          height: 14px;
          margin-right: 7px;
        }

        span {
          color: #fff;
          font-size: 12px;
        }
      }
    }
  }
</style>
<style>
  .el-icon-my-export{
      background: url('~@/assets/images/icon_btn_bc@2x.png') center no-repeat;
      background-size: 13px 13px;
     /* background-size: cover;*/
  }
  .el-icon-my-export:before{
      content: "替";
      font-size: 16px;
      visibility: hidden;
  }


  .el-icon-my-export{
      font-size: 16px;
  }
  .el-icon-my-export:before{
      content: "\e611";
  }
</style>
